@@ -88,9 +88,8 @@ class TorchBackend(Backend):
 
     def numpy(self, tensor):
         if tensor.requires_grad:
-            return tensor.detach().cpu().numpy()
-        else:
-            return tensor.cpu().numpy()
+            tensor = tensor.detach()
+        return tensor.resolve_conj().cpu().numpy()
 
     def to_dlpack(self, tensor):
         from torch.utils import dlpack
